==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/karbon/plugins/tools/KarbonGradientToolFactory.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KarbonGradientToolFactory.h"
#include "KarbonGradientTool.h"

#include <KoToolRegistry.h>

#include <klocale.h>
#include <kdebug.h>

KarbonGradientToolFactory::KarbonGradientToolFactory(QObject *parent)
: KoToolFactory(parent, "KarbonGradientTool", i18n("Gradient tool") )
{
    setToolTip( i18n("Gradient Editing Tool") );
    setToolType( mainToolType() );
    setIcon( "color-fill" );
    setPriority( 3 );
}

KarbonGradientToolFactory::~KarbonGradientToolFactory() {
}

KoTool * KarbonGradientToolFactory::createTool(KoCanvasBase *canvas) {
    return new KarbonGradientTool(canvas);
}

#include "KarbonGradientToolFactory.moc"

==> koffice2_1.9.98.5.orig.tar.gz: koffice-1.9.98.5/karbon/plugins/tools/KarbonGradientToolFactory.cpp <==
/* This file is part of the KDE project
 * Copyright (C) 2007 Jan Hambrecht <jaham@gmx.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "KarbonGradientToolFactory.h"
#include "KarbonGradientTool.h"

#include <KoToolRegistry.h>

#include <klocale.h>
#include <kdebug.h>

KarbonGradientToolFactory::KarbonGradientToolFactory(QObject *parent)
: KoToolFactory(parent, "KarbonGradientTool", i18n("Gradient tool") )
{
    setToolTip( i18n("Gradient Editing Tool") );
    setToolType( mainToolType() );
    setIcon( "format-fill-color" );
    // or probably rather "fill-gradient", please request that icon on TechBase
    setPriority( 3 );
}

KarbonGradientToolFactory::~KarbonGradientToolFactory() {
}

KoTool * KarbonGradientToolFactory::createTool(KoCanvasBase *canvas) {
    return new KarbonGradientTool(canvas);
}

#include "KarbonGradientToolFactory.moc"
